
:orphan:

common
======

Automatically generated index page for common:

.. raw:: html

   <ul>

   </ul>
     <a href="bwaaligner.html">
       <p style="margin-bottom: 5px"><b>Align and sort reads</b> <span style="margin-left: 10px; color: darkgray">BwaAligner</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bwaaligner.html" style="margin-bottom: 10px">
       v<b>1.0.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bwamemsamtoolsview.html">
       <p style="margin-bottom: 5px"><b>Bwa mem + Samtools View</b> <span style="margin-left: 10px; color: darkgray">BwaMemSamtoolsView</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bwamemsamtoolsview.html" style="margin-bottom: 10px">
       v<b>0.7.17|1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="concatstrelkasomaticvcf.html">
       <p style="margin-bottom: 5px"><b>Concat Strelka Somatic Vcf</b> <span style="margin-left: 10px; color: darkgray">ConcatStrelkaSomaticVcf</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="concatstrelkasomaticvcf.html" style="margin-bottom: 10px">
       v<b>0.1.16</b>
     </a></p>
     </a>
     <hr />
         
     <a href="filtervardictsomaticvcf.html">
       <p style="margin-bottom: 5px"><b>Filter Vardict Somatic Vcf</b> <span style="margin-left: 10px; color: darkgray">FilterVardictSomaticVcf</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="filtervardictsomaticvcf.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatkbaserecalbqsrworkflow.html">
       <p style="margin-bottom: 5px"><b>GATK Base Recalibration on Bam</b> <span style="margin-left: 10px; color: darkgray">GATKBaseRecalBQSRWorkflow</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="gatkbaserecalbqsrworkflow.html" style="margin-bottom: 10px">
       v<b>4.1.3</b>
     </a></p>
     </a>
     <hr />
         
     <a href="indexfasta.html">
       <p style="margin-bottom: 5px"><b>Index Fasta reference</b> <span style="margin-left: 10px; color: darkgray">IndexFasta</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="indexfasta.html" style="margin-bottom: 10px">
       v<b>1.0.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="mergeandmarkbams.html">
       <p style="margin-bottom: 5px"><b>Merge and Mark Duplicates</b> <span style="margin-left: 10px; color: darkgray">mergeAndMarkBams</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(3 versions)</span><a class="version-button" href="mergeandmarkbams.html" style="margin-bottom: 10px">
       v<b>4.1.3</b>
     </a></p>
     </a>
     <hr />
         

